function index = vertex_search(XY,vertex)
% This function search the vertex index for which the coordinates of the
% corresponding vertex are nearest to XY.
% Input (1) XY : Nx2 matrix representing the X,Y coordinates of the points.
%       (2) vertex : 3xM matrix representing the X,Y,Z coordinates of the
%                    whole mesh.
% Output (1) index : Nx1 vector containing the vertex indexes of the points
%                    XY.
% Example
% I = vertex_search([0,0],[0,0,0;0,1,0;1,0,0;1,1,0]');

if size(XY,2)~=2
    error('Input feature points must be a Nx2 matrix');
end

k = size(XY,1);
index = zeros(k,1);
for i = 1:k
    [~,index(i,1)] = min(sqrt((vertex(1,:)-XY(i,1)).^2 + (vertex(2,:)-XY(i,2)).^2));
end

if length(unique(index)) ~= length(index)
    warning('Some points are sharing the same vertex index found')
end   