function index = vertex_search3D(XYZ,vertex)
% This function search the vertex index for which the coordinates of the
% corresponding vertex are nearest to XY.
% Input (1) XY : Nx3 matrix representing the X,Y,Z coordinates of the points.
%       (2) vertex : 3xM matrix representing the X,Y,Z coordinates of the
%                    whole mesh.
% Output (1) index : Nx1 vector containing the vertex indexes of the points
%                    XYZ.


if size(XYZ,2)~=3
    error('Input feature points must be a Nx3 matrix');
end

if size(vertex,1)~=3
    error('Input vertex must be a 3xM matrix');
end

k = size(XYZ,1);
index = zeros(k,1);
for i = 1:k
    [~,index(i,1)] = min(sqrt((vertex(1,:)-XYZ(i,1)).^2 + (vertex(2,:)-XYZ(i,2)).^2 + (vertex(3,:)-XYZ(i,3)).^2));
end

if length(unique(index)) ~= length(index)
    warning('Some points are sharing the same vertex index found')
end   